OrderSubscriber

Struct OrderSubscriber 

pub struct OrderSubscriber { /* private fields */ }
A wrapper around a StreamListener that allows subscribing to order updates with a somewhat ergonomic API.

Implementations

Source

impl OrderSubscriber

pub fn new<T: MessageProcessor>( stream_api_connection: &BetfairStreamClient<T>, filter: OrderFilter, ) -> Self

pub async fn subscribe_to_strategy_updates( &mut self, strategy_ref: CustomerStrategyRef, ) -> Result<(), SendError<RequestMessage>>

Create a new market subscriber.

Errors

If the message cannot be sent to the stream.

pub async fn unsubscribe_from_strategy_updates( &mut self, strategy_ref: &CustomerStrategyRef, ) -> Result<(), SendError<RequestMessage>>

Unsubscribe from a market.

Errors

If the message cannot be sent to the stream.

pub async fn unsubscribe_from_all_markets( &mut self, ) -> Result<(), SendError<RequestMessage>>

Unsubscribe from all markets.

Internally it uses a weird trick of subscribing to a market that does not exist to simulate unsubscribing from all markets. betfair docs

Errors

if the message cannot be sent to the stream.

pub async fn resubscribe(&self) -> Result<(), SendError<RequestMessage>>

Resubscribe to the stream.

This is useful when the stream is disconnected and you want to resubscribe to the stream.

Errors

if the stream fails to send the message

pub const fn filter(&self) -> &OrderFilter

pub async fn set_filter( &mut self, filter: OrderFilter, ) -> Result<(), SendError<RequestMessage>>

Set the filter for the subscriber.

Errors

if the stream fails to send the message