pub struct OrderBookCache { /* private fields */ }Expand description
Represents a cache for order book data.
Implementations
Sourceimpl OrderBookCache
Implements methods for managing the order book cache.
impl OrderBookCache
Implements methods for managing the order book cache.
Sourcepub fn new(market_id: MarketId, publish_time: DateTime<Utc>) -> Self
pub fn new(market_id: MarketId, publish_time: DateTime<Utc>) -> Self
Creates a new OrderBookCache with the given market ID and publish time.
Sourcepub fn update_cache(
&mut self,
change: OrderMarketChange,
publish_time: DateTime<Utc>,
)
pub fn update_cache( &mut self, change: OrderMarketChange, publish_time: DateTime<Utc>, )
Updates the cache with changes from the order market.
Sourcepub const fn publish_time(&self) -> DateTime<Utc>
pub const fn publish_time(&self) -> DateTime<Utc>
Returns the publish time of the order book.
Sourcepub const fn runners(
&self,
) -> &HashMap<(SelectionId, Option<Handicap>), OrderBookRunner>
pub const fn runners( &self, ) -> &HashMap<(SelectionId, Option<Handicap>), OrderBookRunner>
Returns a reference to the runners in the order book cache.
Sourcepub fn into_runners(
self,
) -> HashMap<(SelectionId, Option<Handicap>), OrderBookRunner>
pub fn into_runners( self, ) -> HashMap<(SelectionId, Option<Handicap>), OrderBookRunner>
Consumes the OrderBookCache and returns the runners.